LamellarArrayRdmaInput

Enum LamellarArrayRdmaInput 

pub enum LamellarArrayRdmaInput<T: Dist> {
    LamellarMemRegion(LamellarMemoryRegion<T>),
    SharedMemRegion(SharedMemoryRegion<T>),
    LocalMemRegion(OneSidedMemoryRegion<T>),
}
Registered memory regions that can be used as input to various LamellarArray RDMA operations.

Variants



LamellarMemRegion(LamellarMemoryRegion<T>)

Variant contiaining a memory region whose local data can be used as an input buffer



SharedMemRegion(SharedMemoryRegion<T>)

Variant contiaining a shared memory region whose local data can be used as an input buffer



LocalMemRegion(OneSidedMemoryRegion<T>)

Variant contiaining a onessided memory region that can be used as an input buffer