pub struct OneSidedIter<'a, T: Dist + 'static, A: LamellarArrayInternalGet<T>> { /* private fields */ }Expand description
An immutable one sided iterator of a LamellarArray
This struct is created by calling onesided_iter on any of the LamellarArray types
Examples
use lamellar::array::prelude::*;
let world = LamellarWorldBuilder::new().build();
let array = AtomicArray::<usize>::new(&world,100,Distribution::Block).block();
let one_sided_iter = array.onesided_iter();Trait Implementations
Sourceimpl<'a, T: Dist + 'static, A: LamellarArrayInternalGet<T> + Clone + Send> OneSidedIterator for OneSidedIter<'a, T, A>
impl<'a, T: Dist + 'static, A: LamellarArrayInternalGet<T> + Clone + Send> OneSidedIterator for OneSidedIter<'a, T, A>
Sourcefn chunks(self, chunk_size: usize) -> Chunks<Self>
fn chunks(self, chunk_size: usize) -> Chunks<Self>
Split an iterator into fixed-sized chunks Read more
Sourcefn skip(self, count: usize) -> Skip<Self>
fn skip(self, count: usize) -> Skip<Self>
An iterator that skips the first
n elements Read moreSourcefn step_by(self, step_size: usize) -> StepBy<Self>
fn step_by(self, step_size: usize) -> StepBy<Self>
An iterator that steps by
step_size elements Read moreSourcefn zip<I>(self, iter: I) -> Zip<Self, I>
fn zip<I>(self, iter: I) -> Zip<Self, I>
Iterates over tuples
(A,B) where the A items are from self iterator and the B items are from the iter in the argument.
If the two iterators or of unequal length, the returned iterator will be equal in length to the shorter of the two. Read moreSourcefn into_iter(self) -> OneSidedIteratorIter<Self> ⓘ
fn into_iter(self) -> OneSidedIteratorIter<Self> ⓘ
Sourcefn into_stream(self) -> OneSidedStream<Self>
fn into_stream(self) -> OneSidedStream<Self>
impl<'pin, 'a, T: Dist + 'static, A: LamellarArrayInternalGet<T>> Unpin for OneSidedIter<'a, T, A>where
PinnedFieldsOf<__OneSidedIter<'pin, 'a, T, A>>: Unpin,