pub struct NativeAtomicElement<T> { /* private fields */ }Expand description
NativeAtomicElement represents a native (like AtomicUsize, AtomicU8, etc.) atomic element in a NativeAtomicArray.
Implementations
Sourceimpl<T: Dist> NativeAtomicElement<T>
impl<T: Dist> NativeAtomicElement<T>
Sourcepub fn swap(&self, val: T) -> T
pub fn swap(&self, val: T) -> T
Atomically replaces the current value with val and returns the old value.
Sourcepub fn compare_exchange(&self, old: T, new: T) -> Result<T, T>
pub fn compare_exchange(&self, old: T, new: T) -> Result<T, T>
Performs an atomic compare and exchange operation on the atomic element.
The operation succeeds if the current value is equal to old. If successful, it replaces the current value with new and returns the old value.
If the current value is not equal to old, it returns the current value without making any changes.
Sourcepub fn compare_exchange_epsilon(&self, old: T, new: T, eps: T) -> Result<T, T>
pub fn compare_exchange_epsilon(&self, old: T, new: T, eps: T) -> Result<T, T>
Performs an atomic compare and exchange operation with an epsilon value.
This operation succeeds if the absolute difference between the current value and old is less than eps. If successful, it replaces the current value with new and returns the old value.
If the absolute difference is greater than or equal to eps, it returns the current value without making any changes.
Sourcepub fn fetch_add(&self, val: T) -> T
pub fn fetch_add(&self, val: T) -> T
Atomically adds val to the current value and returns the old value.
Sourcepub fn fetch_sub(&self, val: T) -> T
pub fn fetch_sub(&self, val: T) -> T
Atomically subtracts val from the current value and returns the old value.
Sourcepub fn fetch_mul(&self, val: T) -> T
pub fn fetch_mul(&self, val: T) -> T
Atomically multiplies the current value by val and returns the old value.
Sourcepub fn fetch_div(&self, val: T) -> T
pub fn fetch_div(&self, val: T) -> T
Atomically divides the current value by val and returns the old value.
Sourcepub fn fetch_rem(&self, val: T) -> T
pub fn fetch_rem(&self, val: T) -> T
Atomically computes the remainder of the current value divided by val and returns the old value.
Sourceimpl<T: ElementBitWiseOps + 'static> NativeAtomicElement<T>
impl<T: ElementBitWiseOps + 'static> NativeAtomicElement<T>