pub trait _ArrayOps { }Expand description
A marker trait for types that can be used as an array Users should not implement this directly, rather they should use the ArrayOps derive macro by passing it as an argument to the crate::active_messaging::AmData attribute macro to automatically derive this trait.
Examples
// this import includes everything we need
use lamellar::array::prelude::*;
#[lamellar::AmData(
// Lamellar traits
ArrayOps, // needed to derive the ArrayType trait (and additional traits required by the runtime)
Default, // needed to be able to initialize a LamellarArray
// Notice we use `lamellar::AmData` instead of `derive`
// for common traits, e.g. Debug, Clone.
PartialEq, // needed for CompareExchangeEpsilonOps
PartialOrd, // needed for CompareExchangeEpsilonOps
Debug, // any addition traits you want derived
Clone,
)]
struct Custom {
int: usize,
float: f32,
}Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".